@@ -14,13 +14,11 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink.catalog;
 
-import org.apache.commons.compress.utils.Lists;
-import org.apache.doris.flink.table.DorisDynamicTableFactory;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.table.api.Schema;
-import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.AbstractCatalog;
 import org.apache.flink.table.catalog.CatalogBaseTable;
 import org.apache.flink.table.catalog.CatalogDatabase;
@@ -50,6 +48,15 @@ import org.apache.flink.table.factories.Factory;
 import org.apache.flink.table.types.DataType;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
+
+import org.apache.commons.compress.utils.Lists;
+import org.apache.doris.flink.catalog.doris.DorisSchemaFactory;
+import org.apache.doris.flink.catalog.doris.DorisSystem;
+import org.apache.doris.flink.catalog.doris.FieldSchema;
+import org.apache.doris.flink.catalog.doris.TableSchema;
+import org.apache.doris.flink.cfg.DorisConnectionOptions;
+import org.apache.doris.flink.table.DorisDynamicTableFactory;
+import org.apache.doris.flink.tools.cdc.DorisTableConfig;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -57,21 +64,18 @@ import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
-import java.sql.SQLException;
+import java.sql.ResultSetMetaData;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
 import java.util.Optional;
-import java.util.Set;
 import java.util.StringJoiner;
-import java.util.function.Predicate;
 
 import static org.apache.doris.flink.catalog.DorisCatalogOptions.DEFAULT_DATABASE;
-import static org.apache.doris.flink.catalog.DorisCatalogOptions.JDBCURL;
+import static org.apache.doris.flink.catalog.DorisCatalogOptions.getCreateTableProps;
 import static org.apache.doris.flink.table.DorisConfigOptions.FENODES;
 import static org.apache.doris.flink.table.DorisConfigOptions.IDENTIFIER;
 import static org.apache.doris.flink.table.DorisConfigOptions.PASSWORD;
@@ -80,54 +84,29 @@ import static org.apache.doris.flink.table.DorisConfigOptions.TABLE_IDENTIFIER;
 import static org.apache.doris.flink.table.DorisConfigOptions.USERNAME;
 import static org.apache.flink.table.factories.FactoryUtil.CONNECTOR;
 import static org.apache.flink.util.Preconditions.checkArgument;
+import static org.apache.flink.util.Preconditions.checkNotNull;
 
+/** catalog for flink. */
 public class DorisCatalog extends AbstractCatalog {
 
     private static final Logger LOG = LoggerFactory.getLogger(DorisCatalog.class);
-
-    private static final Set<String> builtinDatabases =
-            new HashSet<String>() {
-                {
-                    add("information_schema");
-                }
-            };
-
-    private final String username;
-    private final String password;
-    private final String jdbcUrl;
+    private DorisSystem dorisSystem;
+    private final DorisConnectionOptions connectionOptions;
     private final Map<String, String> properties;
 
     public DorisCatalog(
             String catalogName,
-            String jdbcUrl,
+            DorisConnectionOptions connectionOptions,
             String defaultDatabase,
-            String username,
-            String password,
             Map<String, String> properties) {
         super(catalogName, defaultDatabase);
-
-        checkArgument(
-                !StringUtils.isNullOrWhitespaceOnly(jdbcUrl), "jdbc-url cannot be null or empty");
-        checkArgument(
-                !StringUtils.isNullOrWhitespaceOnly(username), "username cannot be null or empty");
-
-        this.jdbcUrl = jdbcUrl.endsWith("/") ? jdbcUrl : jdbcUrl + "/";
-        ;
-        this.username = username;
-        this.password = password;
+        this.connectionOptions = connectionOptions;
         this.properties = Collections.unmodifiableMap(properties);
     }
 
     @Override
     public void open() throws CatalogException {
-        // test connection, fail early if we cannot connect to database
-        try (Connection conn = DriverManager.getConnection(jdbcUrl, username, password)) {
-        } catch (SQLException e) {
-            throw new ValidationException(
-                    String.format("Failed connecting to %s via JDBC.", jdbcUrl), e);
-        }
-
-        LOG.info("Catalog {} established connection to {}", getName(), jdbcUrl);
+        dorisSystem = new DorisSystem(connectionOptions);
     }
 
     @Override
@@ -148,17 +127,13 @@ public class DorisCatalog extends AbstractCatalog {
 
     @Override
     public List<String> listDatabases() throws CatalogException {
-        return extractColumnValuesBySQL(
-                jdbcUrl,
-                "SELECT `SCHEMA_NAME` FROM `INFORMATION_SCHEMA`.`SCHEMATA`;",
-                1,
-                dbName -> !builtinDatabases.contains(dbName));
+        return dorisSystem.listDatabases();
     }
 
     @Override
     public CatalogDatabase getDatabase(String databaseName)
             throws DatabaseNotExistException, CatalogException {
-        if (listDatabases().contains(databaseName)) {
+        if (databaseExists(databaseName)) {
             return new CatalogDatabaseImpl(Collections.emptyMap(), null);
         } else {
             throw new DatabaseNotExistException(getName(), databaseName);
@@ -168,20 +143,36 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public boolean databaseExists(String databaseName) throws CatalogException {
         checkArgument(!StringUtils.isNullOrWhitespaceOnly(databaseName));
-
         return listDatabases().contains(databaseName);
     }
 
     @Override
     public void createDatabase(String name, CatalogDatabase database, boolean ignoreIfExists)
             throws DatabaseAlreadyExistException, CatalogException {
-        throw new UnsupportedOperationException();
+        if (databaseExists(name)) {
+            if (ignoreIfExists) {
+                return;
+            }
+            throw new DatabaseAlreadyExistException(getName(), name);
+        } else {
+            dorisSystem.createDatabase(name);
+        }
     }
 
     @Override
     public void dropDatabase(String name, boolean ignoreIfNotExists, boolean cascade)
-            throws DatabaseNotEmptyException, CatalogException {
-        throw new UnsupportedOperationException();
+            throws DatabaseNotEmptyException, CatalogException, DatabaseNotExistException {
+        if (!databaseExists(name)) {
+            if (ignoreIfNotExists) {
+                return;
+            }
+            throw new DatabaseNotExistException(getName(), name);
+        }
+
+        if (!cascade && !listTables(name).isEmpty()) {
+            throw new DatabaseNotEmptyException(getName(), name);
+        }
+        dorisSystem.dropDatabase(name);
     }
 
     @Override
@@ -196,13 +187,13 @@ public class DorisCatalog extends AbstractCatalog {
     public List<String> listTables(String databaseName)
             throws DatabaseNotExistException, CatalogException {
         Preconditions.checkState(
-                org.apache.commons.lang3.StringUtils.isNotBlank(databaseName), "Database name must not be blank.");
+                org.apache.commons.lang3.StringUtils.isNotBlank(databaseName),
+                "Database name must not be blank.");
         if (!databaseExists(databaseName)) {
             throw new DatabaseNotExistException(getName(), databaseName);
         }
 
-        return extractColumnValuesBySQL(
-                jdbcUrl + databaseName,
+        return dorisSystem.extractColumnValuesBySQL(
                 "SELECT TABLE_NAME FROM information_schema.`TABLES` WHERE TABLE_SCHEMA = ?",
                 1,
                 null,
@@ -212,7 +203,7 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public List<String> listViews(String databaseName)
             throws DatabaseNotExistException, CatalogException {
-        throw new UnsupportedOperationException();
+        return Collections.emptyList();
     }
 
     @Override
@@ -228,27 +219,42 @@ public class DorisCatalog extends AbstractCatalog {
         if (!props.containsKey(FENODES.key())) {
             props.put(FENODES.key(), queryFenodes());
         }
-        props.put(USERNAME.key(), username);
-        props.put(PASSWORD.key(), password);
+        props.put(USERNAME.key(), connectionOptions.getUsername());
+        props.put(PASSWORD.key(), connectionOptions.getPassword());
         props.put(TABLE_IDENTIFIER.key(), databaseName + "." + tableName);
 
-        String labelPrefix = props.getOrDefault(SINK_LABEL_PREFIX.key(),"");
-        props.put(SINK_LABEL_PREFIX.key(), String.join("_",labelPrefix,databaseName,tableName));
-        //remove catalog option
-        props.remove(JDBCURL.key());
+        String labelPrefix = props.getOrDefault(SINK_LABEL_PREFIX.key(), "");
+        props.put(SINK_LABEL_PREFIX.key(), String.join("_", labelPrefix, databaseName, tableName));
+        // remove catalog option
         props.remove(DEFAULT_DATABASE.key());
-        return CatalogTable.of(createTableSchema(databaseName, tableName), null, Lists.newArrayList(), props);
-
+        return CatalogTable.of(
+                createTableSchema(databaseName, tableName), null, Lists.newArrayList(), props);
     }
 
     @VisibleForTesting
     protected String queryFenodes() {
-        try (Connection conn = DriverManager.getConnection(jdbcUrl, username, password)) {
+        try (Connection conn =
+                DriverManager.getConnection(
+                        connectionOptions.getJdbcUrl(),
+                        connectionOptions.getUsername(),
+                        connectionOptions.getPassword())) {
             StringJoiner fenodes = new StringJoiner(",");
             PreparedStatement ps = conn.prepareStatement("SHOW FRONTENDS");
             ResultSet resultSet = ps.executeQuery();
+
+            // find target ip column name, Version 1.2 is IP, version 2.x is Host
+            String field = "";
+            ResultSetMetaData metaData = resultSet.getMetaData();
+            for (int i = 1; i <= metaData.getColumnCount(); i++) {
+                String columnName = metaData.getColumnName(i);
+                if (columnName.equalsIgnoreCase("IP") || columnName.equalsIgnoreCase("Host")) {
+                    field = columnName;
+                    break;
+                }
+            }
+
             while (resultSet.next()) {
-                String ip = resultSet.getString("IP");
+                String ip = resultSet.getString(field);
                 String port = resultSet.getString("HttpPort");
                 fenodes.add(ip + ":" + port);
             }
@@ -259,11 +265,16 @@ public class DorisCatalog extends AbstractCatalog {
     }
 
     private Schema createTableSchema(String databaseName, String tableName) {
-        String dbUrl = jdbcUrl + databaseName;
-        try (Connection conn = DriverManager.getConnection(dbUrl, username, password)) {
+        try (Connection conn =
+                DriverManager.getConnection(
+                        connectionOptions.getJdbcUrl(),
+                        connectionOptions.getUsername(),
+                        connectionOptions.getPassword())) {
             PreparedStatement ps =
                     conn.prepareStatement(
-                            String.format("SELECT COLUMN_NAME,DATA_TYPE,COLUMN_SIZE,DECIMAL_DIGITS FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA`= '%s' AND `TABLE_NAME`= '%s'", databaseName, tableName));
+                            String.format(
+                                    "SELECT COLUMN_NAME,DATA_TYPE,COLUMN_SIZE,DECIMAL_DIGITS FROM `information_schema`.`COLUMNS` WHERE `TABLE_SCHEMA`= '%s' AND `TABLE_NAME`= '%s'",
+                                    databaseName, tableName));
 
             List<String> columnNames = new ArrayList<>();
             List<DataType> columnTypes = new ArrayList<>();
@@ -273,7 +284,9 @@ public class DorisCatalog extends AbstractCatalog {
                 String columnType = resultSet.getString("DATA_TYPE");
                 long columnSize = resultSet.getLong("COLUMN_SIZE");
                 long columnDigit = resultSet.getLong("DECIMAL_DIGITS");
-                DataType flinkType = DorisTypeMapper.toFlinkType(columnName, columnType, (int) columnSize, (int) columnDigit);
+                DataType flinkType =
+                        DorisTypeMapper.toFlinkType(
+                                columnName, columnType, (int) columnSize, (int) columnDigit);
                 columnNames.add(columnName);
                 columnTypes.add(flinkType);
             }
@@ -282,7 +295,10 @@ public class DorisCatalog extends AbstractCatalog {
             return tableSchema;
         } catch (Exception e) {
             throw new CatalogException(
-                    String.format("Failed getting catalog %s database %s table %s", getName(), databaseName, tableName), e);
+                    String.format(
+                            "Failed getting catalog %s database %s table %s",
+                            getName(), databaseName, tableName),
+                    e);
         }
     }
 
@@ -299,7 +315,15 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public void dropTable(ObjectPath tablePath, boolean ignoreIfNotExists)
             throws TableNotExistException, CatalogException {
-        throw new UnsupportedOperationException();
+        if (!tableExists(tablePath)) {
+            if (ignoreIfNotExists) {
+                return;
+            }
+            throw new TableNotExistException(getName(), tablePath);
+        }
+
+        dorisSystem.dropTable(
+                String.format("%s.%s", tablePath.getDatabaseName(), tablePath.getObjectName()));
     }
 
     @Override
@@ -311,7 +335,55 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public void createTable(ObjectPath tablePath, CatalogBaseTable table, boolean ignoreIfExists)
             throws TableAlreadyExistException, DatabaseNotExistException, CatalogException {
-        throw new UnsupportedOperationException();
+        checkNotNull(tablePath, "tablePath cannot be null");
+        checkNotNull(table, "table cannot be null");
+
+        if (!databaseExists(tablePath.getDatabaseName())) {
+            throw new DatabaseNotExistException(getName(), tablePath.getDatabaseName());
+        }
+        if (tableExists(tablePath)) {
+            if (ignoreIfExists) {
+                return;
+            }
+            throw new TableAlreadyExistException(getName(), tablePath);
+        }
+
+        Map<String, String> options = table.getOptions();
+        if (!IDENTIFIER.equals(options.get(CONNECTOR.key()))) {
+            return;
+        }
+
+        List<String> primaryKeys = getCreateDorisKeys(table.getSchema());
+        TableSchema schema =
+                DorisSchemaFactory.createTableSchema(
+                        tablePath.getDatabaseName(),
+                        tablePath.getObjectName(),
+                        getCreateDorisColumns(table.getSchema()),
+                        primaryKeys,
+                        new DorisTableConfig(getCreateTableProps(options)),
+                        table.getComment());
+
+        dorisSystem.createTable(schema);
+    }
+
+    public List<String> getCreateDorisKeys(org.apache.flink.table.api.TableSchema schema) {
+        Preconditions.checkState(schema.getPrimaryKey().isPresent(), "primary key cannot be null");
+        return schema.getPrimaryKey().get().getColumns();
+    }
+
+    public Map<String, FieldSchema> getCreateDorisColumns(
+            org.apache.flink.table.api.TableSchema schema) {
+        String[] fieldNames = schema.getFieldNames();
+        DataType[] fieldTypes = schema.getFieldDataTypes();
+
+        Map<String, FieldSchema> fields = new LinkedHashMap<>();
+        for (int i = 0; i < fieldNames.length; i++) {
+            fields.put(
+                    fieldNames[i],
+                    new FieldSchema(
+                            fieldNames[i], DorisTypeMapper.toDorisType(fieldTypes[i]), null));
+        }
+        return fields;
     }
 
     @Override
@@ -333,7 +405,7 @@ public class DorisCatalog extends AbstractCatalog {
     public List<CatalogPartitionSpec> listPartitions(
             ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
             throws TableNotExistException, TableNotPartitionedException,
-            PartitionSpecInvalidException, CatalogException {
+                    PartitionSpecInvalidException, CatalogException {
         return Collections.emptyList();
     }
 
@@ -353,7 +425,7 @@ public class DorisCatalog extends AbstractCatalog {
     @Override
     public boolean partitionExists(ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
             throws CatalogException {
-        throw new UnsupportedOperationException();
+        return false;
     }
 
     @Override
@@ -363,8 +435,8 @@ public class DorisCatalog extends AbstractCatalog {
             CatalogPartition partition,
             boolean ignoreIfExists)
             throws TableNotExistException, TableNotPartitionedException,
-            PartitionSpecInvalidException, PartitionAlreadyExistsException,
-            CatalogException {
+                    PartitionSpecInvalidException, PartitionAlreadyExistsException,
+                    CatalogException {
         throw new UnsupportedOperationException();
     }
 
@@ -488,36 +560,13 @@ public class DorisCatalog extends AbstractCatalog {
         throw new UnsupportedOperationException();
     }
 
+    @VisibleForTesting
+    public DorisConnectionOptions getConnectionOptions() {
+        return connectionOptions;
+    }
 
-    private List<String> extractColumnValuesBySQL(
-            String connUrl,
-            String sql,
-            int columnIndex,
-            Predicate<String> filterFunc,
-            Object... params) {
-
-        List<String> columnValues = Lists.newArrayList();
-
-        try (Connection conn = DriverManager.getConnection(connUrl, username, password);
-             PreparedStatement ps = conn.prepareStatement(sql)) {
-            if (Objects.nonNull(params) && params.length > 0) {
-                for (int i = 0; i < params.length; i++) {
-                    ps.setObject(i + 1, params[i]);
-                }
-            }
-            ResultSet rs = ps.executeQuery();
-            while (rs.next()) {
-                String columnValue = rs.getString(columnIndex);
-                if (Objects.isNull(filterFunc) || filterFunc.test(columnValue)) {
-                    columnValues.add(columnValue);
-                }
-            }
-            return columnValues;
-        } catch (Exception e) {
-            throw new CatalogException(
-                    String.format(
-                            "The following SQL query could not be executed (%s): %s", connUrl, sql),
-                    e);
-        }
+    @VisibleForTesting
+    public Map<String, String> getProperties() {
+        return properties;
     }
 }
