@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 
 public class TableSchema {
+    public static final String DORIS_TABLE_REGEX = "^[a-zA-Z][a-zA-Z0-9-_]*$";
     private String database;
     private String table;
     private String tableComment;
@@ -105,4 +106,31 @@ public class TableSchema {
     public Integer getTableBuckets() {
         return tableBuckets;
     }
+
+    @Override
+    public String toString() {
+        return "TableSchema{"
+                + "database='"
+                + database
+                + '\''
+                + ", table='"
+                + table
+                + '\''
+                + ", tableComment='"
+                + tableComment
+                + '\''
+                + ", fields="
+                + fields
+                + ", keys="
+                + String.join(",", keys)
+                + ", model="
+                + model.name()
+                + ", distributeKeys="
+                + String.join(",", distributeKeys)
+                + ", properties="
+                + properties
+                + ", tableBuckets="
+                + tableBuckets
+                + '}';
+    }
 }
