@@ -14,8 +14,10 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink.deserialization;
 
+import org.apache.flink.annotation.PublicEvolving;
 import org.apache.flink.api.java.typeutils.ResultTypeQueryable;
 import org.apache.flink.util.Collector;
 
@@ -25,7 +27,8 @@ import java.util.List;
 /**
  * The deserialization schema describes how to turn the doris list record into data types
  * (Java/Scala objects) that are processed by Flink.
- **/
+ */
+@PublicEvolving
 public interface DorisDeserializationSchema<T> extends Serializable, ResultTypeQueryable<T> {
 
     void deserialize(List<?> record, Collector<T> out) throws Exception;
