@@ -17,6 +17,7 @@
 
 package org.apache.doris.flink.tools.cdc;
 
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.datastream.DataStreamSource;
@@ -27,13 +28,18 @@ import org.apache.flink.util.OutputTag;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
 
+import org.apache.doris.flink.catalog.doris.DorisSchemaFactory;
 import org.apache.doris.flink.catalog.doris.DorisSystem;
 import org.apache.doris.flink.catalog.doris.TableSchema;
 import org.apache.doris.flink.cfg.DorisConnectionOptions;
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
 import org.apache.doris.flink.cfg.DorisOptions;
 import org.apache.doris.flink.cfg.DorisReadOptions;
+import org.apache.doris.flink.exception.DorisSystemException;
 import org.apache.doris.flink.sink.DorisSink;
+import org.apache.doris.flink.sink.schema.SchemaChangeMode;
+import org.apache.doris.flink.sink.writer.WriteMode;
+import org.apache.doris.flink.sink.writer.serializer.DorisRecordSerializer;
 import org.apache.doris.flink.sink.writer.serializer.JsonDebeziumSchemaSerializer;
 import org.apache.doris.flink.table.DorisConfigOptions;
 import org.slf4j.Logger;
@@ -42,6 +48,7 @@ import org.slf4j.LoggerFactory;
 import java.io.Serializable;
 import java.sql.Connection;
 import java.sql.SQLException;
+import java.sql.SQLSyntaxErrorException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -51,11 +58,11 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 import java.util.regex.Pattern;
-import java.util.stream.Collectors;
+
+import static org.apache.flink.cdc.debezium.utils.JdbcUrlUtils.PROPERTIES_PREFIX;
 
 public abstract class DatabaseSync {
     private static final Logger LOG = LoggerFactory.getLogger(DatabaseSync.class);
-    private static final String LIGHT_SCHEMA_CHANGE = "light_schema_change";
     private static final String TABLE_NAME_OPTIONS = "table-name";
 
     protected Configuration config;
@@ -66,13 +73,15 @@ public abstract class DatabaseSync {
     protected Pattern includingPattern;
     protected Pattern excludingPattern;
     protected Map<Pattern, String> multiToOneRulesPattern;
-    protected Map<String, String> tableConfig = new HashMap<>();
+    protected DorisTableConfig dorisTableConfig;
     protected Configuration sinkConfig;
     protected boolean ignoreDefaultValue;
+    protected boolean ignoreIncompatible;
 
     public StreamExecutionEnvironment env;
     private boolean createTableOnly = false;
-    private boolean newSchemaChange;
+    private boolean newSchemaChange = true;
+    private String schemaChangeMode;
     protected String includingTables;
     protected String excludingTables;
     protected String multiToOneOrigin;
@@ -80,7 +89,7 @@ public abstract class DatabaseSync {
     protected String tablePrefix;
     protected String tableSuffix;
     protected boolean singleSink;
-    private final Map<String, String> tableMapping = new HashMap<>();
+    protected final Map<String, String> tableMapping = new HashMap<>();
 
     public abstract void registerDriver() throws SQLException;
 
@@ -102,10 +111,6 @@ public abstract class DatabaseSync {
         this.excludingPattern = excludingTables == null ? null : Pattern.compile(excludingTables);
         this.multiToOneRulesPattern = multiToOneRulesParser(multiToOneOrigin, multiToOneTarget);
         this.converter = new TableNameConverter(tablePrefix, tableSuffix, multiToOneRulesPattern);
-        // default enable light schema change
-        if (!this.tableConfig.containsKey(LIGHT_SCHEMA_CHANGE)) {
-            this.tableConfig.put(LIGHT_SCHEMA_CHANGE, "true");
-        }
     }
 
     public void build() throws Exception {
@@ -113,39 +118,40 @@ public abstract class DatabaseSync {
         DorisSystem dorisSystem = new DorisSystem(options);
 
         List<SourceSchema> schemaList = getSchemaList();
-        Preconditions.checkState(!schemaList.isEmpty(), "No tables to be synchronized.");
-        if (!dorisSystem.databaseExists(database)) {
+        Preconditions.checkState(
+                !schemaList.isEmpty(),
+                "No tables to be synchronized. Please make sure whether the tables that need to be synchronized exist in the corresponding database or schema.");
+
+        if (!StringUtils.isNullOrWhitespaceOnly(database)
+                && !dorisSystem.databaseExists(database)) {
             LOG.info("database {} not exist, created", database);
             dorisSystem.createDatabase(database);
         }
-
         List<String> syncTables = new ArrayList<>();
-        List<String> dorisTables = new ArrayList<>();
+        List<Tuple2<String, String>> dorisTables = new ArrayList<>();
 
-        Map<String, Integer> tableBucketsMap = null;
-        if (tableConfig.containsKey("table-buckets")) {
-            tableBucketsMap = getTableBuckets(tableConfig.get("table-buckets"));
-        }
-        Set<String> bucketsTable = new HashSet<>();
+        Set<String> targetDbSet = new HashSet<>();
         for (SourceSchema schema : schemaList) {
             syncTables.add(schema.getTableName());
+            String targetDb = database;
+            // Synchronize multiple databases using the src database name
+            if (StringUtils.isNullOrWhitespaceOnly(targetDb)) {
+                targetDb = schema.getDatabaseName();
+                targetDbSet.add(targetDb);
+            }
+            if (StringUtils.isNullOrWhitespaceOnly(database)
+                    && !dorisSystem.databaseExists(targetDb)) {
+                LOG.info("database {} not exist, created", targetDb);
+                dorisSystem.createDatabase(targetDb);
+            }
             String dorisTable = converter.convert(schema.getTableName());
-
             // Calculate the mapping relationship between upstream and downstream tables
             tableMapping.put(
-                    schema.getTableIdentifier(), String.format("%s.%s", database, dorisTable));
-            if (!dorisSystem.tableExists(database, dorisTable)) {
-                TableSchema dorisSchema = schema.convertTableSchema(tableConfig);
-                // set doris target database
-                dorisSchema.setDatabase(database);
-                dorisSchema.setTable(dorisTable);
-                if (tableBucketsMap != null) {
-                    setTableSchemaBuckets(tableBucketsMap, dorisSchema, dorisTable, bucketsTable);
-                }
-                dorisSystem.createTable(dorisSchema);
-            }
-            if (!dorisTables.contains(dorisTable)) {
-                dorisTables.add(dorisTable);
+                    schema.getTableIdentifier(), String.format("%s.%s", targetDb, dorisTable));
+            tryCreateTableIfAbsent(dorisSystem, targetDb, dorisTable, schema);
+
+            if (!dorisTables.contains(Tuple2.of(targetDb, dorisTable))) {
+                dorisTables.add(Tuple2.of(targetDb, dorisTable));
             }
         }
         if (createTableOnly) {
@@ -158,23 +164,43 @@ public abstract class DatabaseSync {
             streamSource.sinkTo(buildDorisSink());
         } else {
             SingleOutputStreamOperator<Void> parsedStream =
-                    streamSource.process(new ParsingProcessFunction(converter));
-            for (String table : dorisTables) {
+                    streamSource.process(buildProcessFunction());
+            for (Tuple2<String, String> dbTbl : dorisTables) {
                 OutputTag<String> recordOutputTag =
-                        ParsingProcessFunction.createRecordOutputTag(table);
+                        ParsingProcessFunction.createRecordOutputTag(dbTbl.f1);
                 DataStream<String> sideOutput = parsedStream.getSideOutput(recordOutputTag);
                 int sinkParallel =
                         sinkConfig.getInteger(
                                 DorisConfigOptions.SINK_PARALLELISM, sideOutput.getParallelism());
+                String uidName = getUidName(targetDbSet, dbTbl);
                 sideOutput
-                        .sinkTo(buildDorisSink(table))
+                        .sinkTo(buildDorisSink(dbTbl.f0 + "." + dbTbl.f1))
                         .setParallelism(sinkParallel)
-                        .name(table)
-                        .uid(table);
+                        .name(uidName)
+                        .uid(uidName);
             }
         }
     }
 
+    /**
+     * @param targetDbSet The set of target databases.
+     * @param dbTbl The database-table tuple.
+     * @return The UID of the DataStream.
+     */
+    public String getUidName(Set<String> targetDbSet, Tuple2<String, String> dbTbl) {
+        String uidName;
+        // Determine whether to proceed with multi-database synchronization.
+        // if yes, the UID is composed of `dbname_tablename`, otherwise it is composed of
+        // `tablename`.
+        if (targetDbSet.size() > 1) {
+            uidName = dbTbl.f0 + "_" + dbTbl.f1;
+        } else {
+            uidName = dbTbl.f1;
+        }
+
+        return uidName;
+    }
+
     private DorisConnectionOptions getDorisConnectionOptions() {
         String fenodes = sinkConfig.getString(DorisConfigOptions.FENODES);
         String benodes = sinkConfig.getString(DorisConfigOptions.BENODES);
@@ -199,23 +225,33 @@ public abstract class DatabaseSync {
         return buildDorisSink(null);
     }
 
+    public ParsingProcessFunction buildProcessFunction() {
+        return new ParsingProcessFunction(converter);
+    }
+
     /** create doris sink. */
-    public DorisSink<String> buildDorisSink(String table) {
+    public DorisSink<String> buildDorisSink(String tableIdentifier) {
         String fenodes = sinkConfig.getString(DorisConfigOptions.FENODES);
         String benodes = sinkConfig.getString(DorisConfigOptions.BENODES);
         String user = sinkConfig.getString(DorisConfigOptions.USERNAME);
         String passwd = sinkConfig.getString(DorisConfigOptions.PASSWORD, "");
+        String jdbcUrl = sinkConfig.getString(DorisConfigOptions.JDBC_URL);
 
         DorisSink.Builder<String> builder = DorisSink.builder();
         DorisOptions.Builder dorisBuilder = DorisOptions.builder();
-        dorisBuilder.setFenodes(fenodes).setBenodes(benodes).setUsername(user).setPassword(passwd);
+        dorisBuilder
+                .setJdbcUrl(jdbcUrl)
+                .setFenodes(fenodes)
+                .setBenodes(benodes)
+                .setUsername(user)
+                .setPassword(passwd);
         sinkConfig
                 .getOptional(DorisConfigOptions.AUTO_REDIRECT)
                 .ifPresent(dorisBuilder::setAutoRedirect);
 
         // single sink not need table identifier
-        if (!singleSink && !StringUtils.isNullOrWhitespaceOnly(table)) {
-            dorisBuilder.setTableIdentifier(database + "." + table);
+        if (!singleSink && !StringUtils.isNullOrWhitespaceOnly(tableIdentifier)) {
+            dorisBuilder.setTableIdentifier(tableIdentifier);
         }
 
         Properties pro = new Properties();
@@ -239,10 +275,10 @@ public abstract class DatabaseSync {
                 .ifPresent(executionBuilder::setBufferCount);
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_BUFFER_SIZE)
-                .ifPresent(executionBuilder::setBufferSize);
+                .ifPresent(v -> executionBuilder.setBufferSize((int) v.getBytes()));
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_CHECK_INTERVAL)
-                .ifPresent(executionBuilder::setCheckInterval);
+                .ifPresent(v -> executionBuilder.setCheckInterval((int) v.toMillis()));
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_MAX_RETRIES)
                 .ifPresent(executionBuilder::setMaxRetries);
@@ -268,7 +304,7 @@ public abstract class DatabaseSync {
                 .ifPresent(executionBuilder::setBufferFlushMaxRows);
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_MAX_BYTES)
-                .ifPresent(executionBuilder::setBufferFlushMaxBytes);
+                .ifPresent(v -> executionBuilder.setBufferFlushMaxBytes((int) v.getBytes()));
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_BUFFER_FLUSH_INTERVAL)
                 .ifPresent(v -> executionBuilder.setBufferFlushIntervalMs(v.toMillis()));
@@ -276,25 +312,36 @@ public abstract class DatabaseSync {
         sinkConfig
                 .getOptional(DorisConfigOptions.SINK_USE_CACHE)
                 .ifPresent(executionBuilder::setUseCache);
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_WRITE_MODE)
+                .ifPresent(v -> executionBuilder.setWriteMode(WriteMode.of(v)));
+        sinkConfig
+                .getOptional(DorisConfigOptions.SINK_IGNORE_COMMIT_ERROR)
+                .ifPresent(executionBuilder::setIgnoreCommitError);
 
         DorisExecutionOptions executionOptions = executionBuilder.build();
         builder.setDorisReadOptions(DorisReadOptions.builder().build())
                 .setDorisExecutionOptions(executionOptions)
-                .setSerializer(
-                        JsonDebeziumSchemaSerializer.builder()
-                                .setDorisOptions(dorisBuilder.build())
-                                .setNewSchemaChange(newSchemaChange)
-                                .setExecutionOptions(executionOptions)
-                                .setTableMapping(tableMapping)
-                                .setTableProperties(tableConfig)
-                                .setTargetDatabase(database)
-                                .setTargetTablePrefix(tablePrefix)
-                                .setTargetTableSuffix(tableSuffix)
-                                .build())
+                .setSerializer(buildSchemaSerializer(dorisBuilder, executionOptions))
                 .setDorisOptions(dorisBuilder.build());
         return builder.build();
     }
 
+    public DorisRecordSerializer<String> buildSchemaSerializer(
+            DorisOptions.Builder dorisBuilder, DorisExecutionOptions executionOptions) {
+        return JsonDebeziumSchemaSerializer.builder()
+                .setDorisOptions(dorisBuilder.build())
+                .setNewSchemaChange(newSchemaChange)
+                .setSchemaChangeMode(schemaChangeMode)
+                .setExecutionOptions(executionOptions)
+                .setTableMapping(tableMapping)
+                .setDorisTableConf(dorisTableConfig)
+                .setTargetDatabase(database)
+                .setTargetTablePrefix(tablePrefix)
+                .setTargetTableSuffix(tableSuffix)
+                .build();
+    }
+
     /** Filter table that need to be synchronized. */
     protected boolean isSyncNeeded(String tableName) {
         boolean sync = true;
@@ -310,9 +357,7 @@ public abstract class DatabaseSync {
 
     protected String getSyncTableList(List<String> syncTables) {
         if (!singleSink) {
-            return syncTables.stream()
-                    .map(v -> getTableListPrefix() + "\\." + v)
-                    .collect(Collectors.joining("|"));
+            return String.format("(%s)\\.(%s)", getTableListPrefix(), String.join("|", syncTables));
         } else {
             // includingTablePattern and ^excludingPattern
             if (includingTables == null) {
@@ -325,7 +370,7 @@ public abstract class DatabaseSync {
             } else {
                 String excludingPattern =
                         String.format("?!(%s\\.(%s))$", getTableListPrefix(), excludingTables);
-                return String.format("(%s)(%s)", includingPattern, excludingPattern);
+                return String.format("(%s)(%s)", excludingPattern, includingPattern);
             }
         }
     }
@@ -362,7 +407,8 @@ public abstract class DatabaseSync {
      * @param tableBuckets the string of tableBuckets, eg:student:10,student_info:20,student.*:30
      * @return The table name and buckets map. The key is table name, the value is buckets.
      */
-    public Map<String, Integer> getTableBuckets(String tableBuckets) {
+    @Deprecated
+    public static Map<String, Integer> getTableBuckets(String tableBuckets) {
         Map<String, Integer> tableBucketsMap = new LinkedHashMap<>();
         String[] tableBucketsArray = tableBuckets.split(",");
         for (String tableBucket : tableBucketsArray) {
@@ -382,6 +428,7 @@ public abstract class DatabaseSync {
      * @param dorisTable the table name need to set buckets
      * @param tableHasSet The buckets table is set
      */
+    @Deprecated
     public void setTableSchemaBuckets(
             Map<String, Integer> tableBucketsMap,
             TableSchema dorisSchema,
@@ -411,6 +458,54 @@ public abstract class DatabaseSync {
         }
     }
 
+    private void tryCreateTableIfAbsent(
+            DorisSystem dorisSystem, String targetDb, String dorisTable, SourceSchema schema) {
+        if (!dorisSystem.tableExists(targetDb, dorisTable)) {
+            TableSchema dorisSchema =
+                    DorisSchemaFactory.createTableSchema(
+                            database,
+                            dorisTable,
+                            schema.getFields(),
+                            schema.getPrimaryKeys(),
+                            dorisTableConfig,
+                            schema.getTableComment());
+            try {
+                dorisSystem.createTable(dorisSchema);
+            } catch (Exception ex) {
+                handleTableCreationFailure(ex);
+            }
+        }
+    }
+
+    private void handleTableCreationFailure(Exception ex) throws DorisSystemException {
+        if (ignoreIncompatible && ex.getCause() instanceof SQLSyntaxErrorException) {
+            LOG.warn(
+                    "Doris schema and source table schema are not compatible. Error: {} ",
+                    ex.getCause().toString());
+        } else {
+            throw new DorisSystemException("Failed to create table due to: ", ex);
+        }
+    }
+
+    protected Properties getJdbcProperties() {
+        Properties jdbcProps = new Properties();
+        for (Map.Entry<String, String> entry : config.toMap().entrySet()) {
+            String key = entry.getKey();
+            String value = entry.getValue();
+            if (key.startsWith(PROPERTIES_PREFIX)) {
+                jdbcProps.put(key.substring(PROPERTIES_PREFIX.length()), value);
+            }
+        }
+        return jdbcProps;
+    }
+
+    protected String getJdbcUrlTemplate(String initialJdbcUrl, Properties jdbcProperties) {
+        StringBuilder jdbcUrlBuilder = new StringBuilder(initialJdbcUrl);
+        jdbcProperties.forEach(
+                (key, value) -> jdbcUrlBuilder.append("&").append(key).append("=").append(value));
+        return jdbcUrlBuilder.toString();
+    }
+
     public DatabaseSync setEnv(StreamExecutionEnvironment env) {
         this.env = env;
         return this;
@@ -446,13 +541,19 @@ public abstract class DatabaseSync {
         return this;
     }
 
+    @Deprecated
     public DatabaseSync setTableConfig(Map<String, String> tableConfig) {
         if (!CollectionUtil.isNullOrEmpty(tableConfig)) {
-            this.tableConfig = tableConfig;
+            this.dorisTableConfig = new DorisTableConfig(tableConfig);
         }
         return this;
     }
 
+    public DatabaseSync setTableConfig(DorisTableConfig tableConfig) {
+        this.dorisTableConfig = tableConfig;
+        return this;
+    }
+
     public DatabaseSync setSinkConfig(Configuration sinkConfig) {
         this.sinkConfig = sinkConfig;
         return this;
@@ -473,11 +574,25 @@ public abstract class DatabaseSync {
         return this;
     }
 
+    public DatabaseSync setSchemaChangeMode(String schemaChangeMode) {
+        if (org.apache.commons.lang3.StringUtils.isEmpty(schemaChangeMode)) {
+            this.schemaChangeMode = SchemaChangeMode.DEBEZIUM_STRUCTURE.getName();
+            return this;
+        }
+        this.schemaChangeMode = schemaChangeMode.trim();
+        return this;
+    }
+
     public DatabaseSync setSingleSink(boolean singleSink) {
         this.singleSink = singleSink;
         return this;
     }
 
+    public DatabaseSync setIgnoreIncompatible(boolean ignoreIncompatible) {
+        this.ignoreIncompatible = ignoreIncompatible;
+        return this;
+    }
+
     public DatabaseSync setTablePrefix(String tablePrefix) {
         this.tablePrefix = tablePrefix;
         return this;
