@@ -14,12 +14,12 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+
 package org.apache.doris.flink;
 
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.Table;
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
-import org.apache.flink.types.Row;
 
 public class DorisSourceExample {
 
@@ -32,34 +32,33 @@ public class DorisSourceExample {
 
         // register a table in the catalog
         tEnv.executeSql(
-                "CREATE TABLE doris_source (" +
-                        "bigint_1 BIGINT," +
-                        "char_1 STRING," +
-                        "date_1 STRING," +
-                        "datetime_1 STRING," +
-                        "decimal_1 DECIMAL(5,2)," +
-                        "double_1 DOUBLE," +
-                        "float_1 FLOAT ," +
-                        "int_1 INT ," +
-                        "largeint_1 STRING, " +
-                        "smallint_1 SMALLINT, " +
-                        "tinyint_1 TINYINT, " +
-                        "varchar_1 STRING " +
-                        ") " +
-                        "WITH (\n" +
-                        "  'connector' = 'doris',\n" +
-                        "  'fenodes' = 'FE_IP:8030',\n" +
-                        "  'table.identifier' = 'db.table',\n" +
-                        "  'doris.filter.query' = 'bigint_1=1',\n" +
-                        "  'username' = 'root',\n" +
-                        "  'password' = ''\n" +
-                        ")");
+                "CREATE TABLE doris_source ("
+                        + "bigint_1 BIGINT,"
+                        + "char_1 STRING,"
+                        + "date_1 STRING,"
+                        + "datetime_1 STRING,"
+                        + "decimal_1 DECIMAL(5,2),"
+                        + "double_1 DOUBLE,"
+                        + "float_1 FLOAT ,"
+                        + "int_1 INT ,"
+                        + "largeint_1 STRING, "
+                        + "smallint_1 SMALLINT, "
+                        + "tinyint_1 TINYINT, "
+                        + "varchar_1 STRING "
+                        + ") "
+                        + "WITH (\n"
+                        + "  'connector' = 'doris',\n"
+                        + "  'fenodes' = 'FE_IP:8030',\n"
+                        + "  'table.identifier' = 'db.table',\n"
+                        + "  'username' = 'root',\n"
+                        + "  'password' = ''\n"
+                        + ")");
 
         // define a dynamic aggregating query
-        final Table result = tEnv.sqlQuery("SELECT * from doris_source  ");
+        final Table result = tEnv.sqlQuery("SELECT * from doris_source ");
 
         // print the result to the console
-        tEnv.toRetractStream(result, Row.class).print();
+        tEnv.toDataStream(result).print();
         env.execute();
     }
 }
