@@ -17,9 +17,12 @@
 
 package org.apache.doris.flink.tools.cdc;
 
+import org.apache.flink.cdc.connectors.mysql.source.config.MySqlSourceOptions;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 
+import org.apache.doris.flink.sink.schema.SchemaChangeMode;
+import org.apache.doris.flink.table.DorisConfigOptions;
 import org.apache.doris.flink.tools.cdc.mysql.MysqlDatabaseSync;
 
 import java.util.HashMap;
@@ -31,7 +34,7 @@ public class CdcMysqlSyncDatabaseCase {
     public static void main(String[] args) throws Exception {
 
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-        //        env.setParallelism(1);
+        // env.setParallelism(1);
 
         Map<String, String> flinkMap = new HashMap<>();
         flinkMap.put("execution.checkpointing.interval", "10s");
@@ -45,33 +48,37 @@ public class CdcMysqlSyncDatabaseCase {
         String tablePrefix = "";
         String tableSuffix = "";
         Map<String, String> mysqlConfig = new HashMap<>();
-        mysqlConfig.put("database-name", "db1");
-        mysqlConfig.put("hostname", "127.0.0.1");
-        mysqlConfig.put("port", "3306");
-        mysqlConfig.put("username", "root");
-        // mysqlConfig.put("password","");
-        mysqlConfig.put("password", "12345678");
+        mysqlConfig.put(MySqlSourceOptions.DATABASE_NAME.key(), "test");
+        mysqlConfig.put(MySqlSourceOptions.HOSTNAME.key(), "127.0.0.1");
+        mysqlConfig.put(MySqlSourceOptions.PORT.key(), "3306");
+        mysqlConfig.put(MySqlSourceOptions.USERNAME.key(), "root");
+        mysqlConfig.put(MySqlSourceOptions.PASSWORD.key(), "12345678");
+        // add jdbc properties for MySQL
+        mysqlConfig.put("jdbc.properties.use_ssl", "false");
         Configuration config = Configuration.fromMap(mysqlConfig);
 
         Map<String, String> sinkConfig = new HashMap<>();
-        sinkConfig.put("fenodes", "10.20.30.1:8030");
-        // sinkConfig.put("benodes","10.20.30.1:8040, 10.20.30.2:8040, 10.20.30.3:8040");
-        sinkConfig.put("username", "root");
-        sinkConfig.put("password", "");
-        sinkConfig.put("jdbc-url", "jdbc:mysql://10.20.30.1:9030");
-        sinkConfig.put("sink.label-prefix", UUID.randomUUID().toString());
+        sinkConfig.put(DorisConfigOptions.FENODES.key(), "10.20.30.1:8030");
+        sinkConfig.put(DorisConfigOptions.USERNAME.key(), "root");
+        sinkConfig.put(DorisConfigOptions.PASSWORD.key(), "");
+        sinkConfig.put(DorisConfigOptions.JDBC_URL.key(), "jdbc:mysql://10.20.30.1:9030");
+        sinkConfig.put(DorisConfigOptions.SINK_LABEL_PREFIX.key(), UUID.randomUUID().toString());
+        sinkConfig.put("sink.enable-delete", "false");
         Configuration sinkConf = Configuration.fromMap(sinkConfig);
 
         Map<String, String> tableConfig = new HashMap<>();
-        tableConfig.put("replication_num", "1");
-        tableConfig.put("table-buckets", "tbl1:10,tbl2:20,a.*:30,b.*:40,.*:50");
+        tableConfig.put(DatabaseSyncConfig.REPLICATION_NUM, "1");
+        tableConfig.put(DatabaseSyncConfig.TABLE_BUCKETS, "tbl1:10,tbl2:20,a.*:30,b.*:40,.*:50");
         // String includingTables = "tbl1|tbl2|tbl3";
         String includingTables = "a_.*|b_.*|c";
         String excludingTables = "";
         String multiToOneOrigin = "a_.*|b_.*";
         String multiToOneTarget = "a|b";
         boolean ignoreDefaultValue = false;
-        boolean useNewSchemaChange = false;
+        boolean useNewSchemaChange = true;
+        String schemaChangeMode = SchemaChangeMode.DEBEZIUM_STRUCTURE.getName();
+        boolean singleSink = false;
+        boolean ignoreIncompatible = false;
         DatabaseSync databaseSync = new MysqlDatabaseSync();
         databaseSync
                 .setEnv(env)
@@ -88,6 +95,9 @@ public class CdcMysqlSyncDatabaseCase {
                 .setTableConfig(tableConfig)
                 .setCreateTableOnly(false)
                 .setNewSchemaChange(useNewSchemaChange)
+                .setSchemaChangeMode(schemaChangeMode)
+                .setSingleSink(singleSink)
+                .setIgnoreIncompatible(ignoreIncompatible)
                 .create();
         databaseSync.build();
         env.execute(String.format("MySQL-Doris Database Sync: %s", database));
